==> vlc-ios-3.5.6.tar.gz: vlc-ios-3.5.6/Sources/Headers/VLC-iOS-Bridging-Header.h <==
#import <AppAuth/AppAuth.h>
#import <MobileVLCKit/MobileVLCKit.h>
#import <ObjectiveDropboxOfficial/ObjectiveDropboxOfficial.h>
#import <VLCMediaLibraryKit/VLCMediaLibraryKit.h>
#import <XKKeychain/XKKeychain.h>
#import "VLCExternalDisplayController.h"
#import "UIColor+Presets.h"
#import "VLCAppDelegate.h"
#import "VLCAppCoordinator.h"
#import "VLCCloudServicesTableViewController.h"
#import "VLCConstants.h"
#import "VLCDownloadController.h"
#import "VLCDownloadViewController.h"
#import "VLCEmptyLibraryView.h"
#import "VLCOpenNetworkStreamViewController.h"
#import "VLCNetworkLoginViewController.h"
#import "VLCPlaybackService+MediaLibrary.h"
#import "VLCPlaybackNavigationController.h"
#import "VLCPlayerDisplayController.h"
#import "VLCServerListViewController.h"
#import "VLCSlider.h"
#import "VLCWiFiUploadTableViewCell.h"
#import "IASKSettingsReader.h"
#import "IASKSwitch.h"
#import "VLCHTTPUploaderController.h"
#import "VLCActivityViewControllerVendor.h"
#import "VLCMediaFileDiscoverer.h"
#import "VLCMigrationViewController.h"
#import "VLCCloudStorageTableViewController.h"
#import "VLCCloudStorageTableViewCell.h"
#import "VLCMetadata.h"
#import "VLCPlayerDisplayController.h"
#import "NSString+SupportedMedia.h"
#import "VLCFirstStepsViewController.h"
#import "VLCPlaybackInfoSubtitlesFetcherViewController.h"
#import "VLCDropboxConstants.h"
#import "VLCStatusLabel.h"
#import "VLCThumbnailsCache.h"
#import "VLCGoogleDriveTableViewController.h"
#import "VLCGoogleDriveConstants.h"
#import "VLCMLMedia+App.h"
#import "VLCNonInteractiveWindowSceneDelegate.h"
#import "VLCNetworkListCell.h"
#import "VLCNetworkServerBrowserViewController.h"
#import "VLCLocalNetworkServiceBrowserDSM.h"
#import "UIImage+AverageColor.h"
#import "VLCFavoriteService.h"
#import "VLCDonationViewController.h"
#import "VLCDonationNagScreenViewController.h"

==> vlc-ios-3.5.9.tar.gz: vlc-ios-3.5.9/Sources/Headers/VLC-iOS-Bridging-Header.h <==
#import <AppAuth/AppAuth.h>
#import <MobileVLCKit/MobileVLCKit.h>
#import <ObjectiveDropboxOfficial/ObjectiveDropboxOfficial.h>
#import <VLCMediaLibraryKit/VLCMediaLibraryKit.h>
#import <XKKeychain/XKKeychain.h>
#import "VLCExternalDisplayController.h"
#import "UIColor+Presets.h"
#import "VLCAppDelegate.h"
#import "VLCAppCoordinator.h"
#import "VLCCloudServicesTableViewController.h"
#import "VLCConstants.h"
#import "VLCDownloadController.h"
#import "VLCDownloadViewController.h"
#import "VLCEmptyLibraryView.h"
#import "VLCOpenNetworkStreamViewController.h"
#import "VLCNetworkLoginViewController.h"
#import "VLCPlaybackService+MediaLibrary.h"
#import "VLCPlaybackNavigationController.h"
#import "VLCPlayerDisplayController.h"
#import "VLCServerListViewController.h"
#import "VLCSlider.h"
#import "VLCWiFiUploadTableViewCell.h"
#import "IASKSettingsReader.h"
#import "IASKSwitch.h"
#import "VLCHTTPUploaderController.h"
#import "VLCActivityViewControllerVendor.h"
#import "VLCMediaFileDiscoverer.h"
#import "VLCMigrationViewController.h"
#import "VLCCloudStorageTableViewController.h"
#import "VLCCloudStorageTableViewCell.h"
#import "VLCMetadata.h"
#import "VLCPlayerDisplayController.h"
#import "NSString+SupportedMedia.h"
#import "VLCFirstStepsViewController.h"
#import "VLCPlaybackInfoSubtitlesFetcherViewController.h"
#import "VLCDropboxConstants.h"
#import "VLCStatusLabel.h"
#import "VLCThumbnailsCache.h"
#import "VLCGoogleDriveTableViewController.h"
#import "VLCGoogleDriveConstants.h"
#import "VLCMLMedia+App.h"
#import "VLCNonInteractiveWindowSceneDelegate.h"
#import "VLCNetworkListCell.h"
#import "VLCNetworkServerBrowserViewController.h"
#import "VLCLocalNetworkServiceBrowserDSM.h"
#import "UIImage+AverageColor.h"
#import "VLCFavoriteService.h"
#import "VLCDonationViewController.h"
#import "VLCDonationNagScreenViewController.h"

#import "VLCNetworkServerLoginInformation.h"
#import "VLCNetworkServerBrowserPlex.h"
#import "VLCNetworkServerBrowserVLCMedia.h"
#import "VLCLocalNetworkServiceBrowserPlex.h"
#import "VLCNetworkServerBrowserVLCMedia+FTP.h"
#import "VLCLocalNetworkServiceBrowserDSM.h"
#import "VLCLocalNetworkServiceBrowserNFS.h"
#import "VLCNetworkServerBrowserVLCMedia+SFTP.h"
#import "VLCLocalNetworkServiceBrowserUPnP.h"
